summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorDavid Gilbert <david.gilbert@object-refinery.com>2006-03-03 13:20:03 +0000
committerDavid Gilbert <david.gilbert@object-refinery.com>2006-03-03 13:20:03 +0000
commitc737a8a1153c9f928ab77b3a714cbe5251e06eca (patch)
tree9533c0acd46e93fd77c62730aca544fc3c2372d4
parent85b35b1bda7ca489cbe770303289ed28c2a49363 (diff)
downloadclasspath-c737a8a1153c9f928ab77b3a714cbe5251e06eca.tar.gz
2006-03-03 David Gilbert <david.gilbert@object-refinery.com>
* javax/swing/CellRendererPane.java: Minor API doc fix, * javax/swing/ComboBoxModel.java: Updated API docs.
-rw-r--r--ChangeLog5
-rw-r--r--javax/swing/CellRendererPane.java4
-rw-r--r--javax/swing/ComboBoxModel.java28
3 files changed, 22 insertions, 15 deletions
diff --git a/ChangeLog b/ChangeLog
index 5985f7d20..8414cb551 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,8 @@
+2006-03-03 David Gilbert <david.gilbert@object-refinery.com>
+
+ * javax/swing/CellRendererPane.java: Minor API doc fix,
+ * javax/swing/ComboBoxModel.java: Updated API docs.
+
2006-03-03 Chris Burdess <dog@gnu.org>
Fixes PR 26503
diff --git a/javax/swing/CellRendererPane.java b/javax/swing/CellRendererPane.java
index 6d7b42a12..b3d6f6a73 100644
--- a/javax/swing/CellRendererPane.java
+++ b/javax/swing/CellRendererPane.java
@@ -1,5 +1,5 @@
/* CellRendererPane.java --
- Copyright (C) 2002, 2004 Free Software Foundation, Inc.
+ Copyright (C) 2002, 2004, 2006, Free Software Foundation, Inc.
This file is part of GNU Classpath.
@@ -75,7 +75,7 @@ public class CellRendererPane extends Container implements Accessible
/**
* getAccessibleRole
- * @returns AccessibleRole
+ * @return AccessibleRole
*/
public AccessibleRole getAccessibleRole()
{
diff --git a/javax/swing/ComboBoxModel.java b/javax/swing/ComboBoxModel.java
index 6968db490..610527587 100644
--- a/javax/swing/ComboBoxModel.java
+++ b/javax/swing/ComboBoxModel.java
@@ -1,5 +1,5 @@
/* ComboBoxModel.java --
- Copyright (C) 2002 Free Software Foundation, Inc.
+ Copyright (C) 2002, 2006, Free Software Foundation, Inc.
This file is part of GNU Classpath.
@@ -37,31 +37,33 @@ exception statement from your version. */
package javax.swing;
+import javax.swing.event.ListDataEvent;
+import javax.swing.event.ListDataListener;
/**
* The data model for {@link JComboBox}. This model keeps
* track of elements contained in the JComboBox as well as the current
* combo box selection. Whenever selection in the JComboBox changes, the
* ComboBoxModel should fire ListDataEvents to ComboBox's ListDataListeners.
*
* @author Andrew Selkirk
*/
public interface ComboBoxModel extends ListModel
{
/**
* This method sets the selected item in the combo box. Class
* implementing this interface should fire ListDataEvents to
* all registered ListDataListeners to indicated that the
* selection has changed.
*
- * @param item item in the combo box that should be selected
+ * @param item the selected item (<code>null</code> permitted).
*/
void setSelectedItem(Object item);
/**
- * The method returns currently selected item in the combo box
+ * Returns the currently selected item in the combo box.
*
- * @returns item that is currently selected in the combo box.
+ * @return The selected item (possibly <code>null</code>).
*/
Object getSelectedItem();
-} // ComboBoxModel
+}
@@ -37,31 +37,33 @@ exception statement from your version. */
/**
- * The data model for {@link JComboBox}. This model keeps
- * track of elements contained in the JComboBox as well as the current
- * combo box selection. Whenever selection in the JComboBox changes, the
- * ComboBoxModel should fire ListDataEvents to ComboBox's ListDataListeners.
+ * The data model for a {@link JComboBox}. This model keeps track of elements
+ * contained in the <code>JComboBox</code> as well as the current
+ * combo box selection. Whenever the selection in the <code>JComboBox</code>
+ * changes, the <code>ComboBoxModel</code> should fire a {@link ListDataEvent}
+ * to the model's {@link ListDataListener}s.
*
* @author Andrew Selkirk
@@ -37,31 +37,33 @@ exception statement from your version. */
{
/**
- * This method sets the selected item in the combo box. Class
- * implementing this interface should fire ListDataEvents to
- * all registered ListDataListeners to indicated that the
- * selection has changed.
+ * Sets the selected item in the combo box. Classes implementing this
+ * interface should fire a {@link ListDataEvent} to all registered
+ * {@link ListDataListener}s to indicate that the selection has changed.
*